<template>
  <!-- 安全隐患排查记录添加 -->
  <div>
    <el-dialog
      :close-on-click-modal="false"
      :title="'安全隐患检查记录'"
      :visible.sync="showFormDia"
      width="86%"
      :before-close="handleClose"
      top="4vh"
    >
      <div>
        <template slot="title">
          <span class="collapse-title">
            <i class="collapse-title-icon el-icon-warning" />
            安全隐患检查记录
          </span>
        </template>
        <el-table
          ref="singleTable"
          :data="params"
          style="width: 100%"
          highlight-current-row
          :cell-style="{'text-align': 'center'}"
          :header-cell-style="{'text-align': 'center'}"
        >
          <el-table-column fixed type="index" width="55" label="序号" />
          <!-- <el-table-column label="排查年度" min-width="50" prop="checkYear"></el-table-column> -->
          <el-table-column label="参考依据说明" min-width="50" prop="reference">
            <template slot-scope="scope">
              <el-input v-model="scope.row.reference"></el-input>
            </template>
          </el-table-column>
          <el-table-column label="检查时间" min-width="50" prop="checkDate">
            <template slot-scope="scope">
              <el-date-picker
                v-model="scope.row.checkDate"
                size="small"
                type="date"
                value-format="yyyy-MM-dd"
                placeholder="请选择开始时间"
              />
            </template>
          </el-table-column>
          <el-table-column
            label="是否重大隐患"
            min-width="50"
            prop="greatDanger"
          >
            <template slot-scope="scope">
              <el-select
                v-model="scope.row.greatDanger"
                style="width:100%"
                clearable
                placeholder="请选择是否重大隐患"
              >
                <el-option
                  v-for="item in greatDangerList"
                  :key="item.value"
                  :label="item.name"
                  :value="item.value"
                />
              </el-select>
            </template>
          </el-table-column>
          <el-table-column label="隐患内容" min-width="50" prop="dangerContent">
            <template slot-scope="scope">
              <el-input v-model="scope.row.dangerContent"></el-input>
            </template>
          </el-table-column>
          <el-table-column label="整改期限" min-width="50" prop="timeLimit">
            <template slot-scope="scope">
              <el-input v-model="scope.row.timeLimit"></el-input>
            </template>
          </el-table-column>
          <el-table-column label="隐患图片" min-width="50" prop="imgs">
            <template slot-scope="scope">
              <el-upload
                :disabled="true"
                name="files"
                :action="uploadUrl"
                :headers="header"
                accept="image/jpg,image/jpeg,image/png"
                :data="{bizCode: 'Image', bizId: ''}"
                :on-success="
                  (response, file, fileList) => {
                    return handleAvatarSuccess(
                      response,
                      file,
                      fileList,
                      scope.row
                    )
                  }
                "
                :before-upload="beforeAvatarUpload"
                list-type="picture-card"
                :on-remove="
                  (file, fileList) => {
                    return handleRemove(file, fileList, scope.row)
                  }
                "
                :file-list="scope.row.imgs"
              >
                <i slot="default" class="el-icon-plus" />
              </el-upload>
            </template>
          </el-table-column>
          <el-table-column label="整改后图片" min-width="50" prop="reformImgs">
            <template slot-scope="scope">
              <el-upload
                name="files"
                :action="uploadUrl"
                :headers="header"
                accept="image/jpg,image/jpeg,image/png"
                :data="{bizCode: 'Image', bizId: ''}"
                :on-success="
                  (response, file, fileList) => {
                    return handleAvatarSuccess1(
                      response,
                      file,
                      fileList,
                      scope.row
                    )
                  }
                "
                :before-upload="beforeAvatarUpload"
                list-type="picture-card"
                :on-remove="
                  (file, fileList) => {
                    return handleRemove1(file, fileList, scope.row)
                  }
                "
                :file-list="scope.row.reformImgs"
              >
                <i slot="default" class="el-icon-plus" />
              </el-upload>
            </template>
          </el-table-column>
        </el-table>
      </div>
      <span slot="footer" class="dialog-footer">
        <el-button type="primary" @click="handleSave">保 存</el-button>
        <el-button @click="handleClose">取 消</el-button>
      </span>
    </el-dialog>
    <el-dialog :visible.sync="dialogVisible">
      <img width="100%" :src="dialogImageUrl" alt="" />
    </el-dialog>
  </div>
</template>

<script>
import CmgtSaftyDangerCheckrecordApi from '@/views/Manage/saftyDanger/api/CmgtSaftyDangerCheckrecordApi'
import dictContracts from '@/components/dict/DictSelectUtils.js'
import CmgtSaftyDangerCheckplanApi from '@/views/Manage/saftyDanger/api/CmgtSaftyDangerCheckplanApi'
import {mapState} from 'vuex'

export default {
  name: 'CmgtSaftyDangerCheckrecordFormDialog',
  components: {},
  props: {
    handleFcData: Array
  },
  data() {
    return {
      uploadUrl: window.context.portal + '/file/v1/uploadFileForConfig', // 服务器上传地址
      previewUrl:
        window.context.portal + '/file/onlinePreviewController/v1/getFileById_',
      showFormDia: false,
      activeCollapseNames: ['1', '2', '3'],
      labelStyle: {
        width: '25px'
      },
      params: [],
      rules: {
        recipient: [
          {
            required: true,
            message: '排查单位不能为空',
            trigger: 'blur'
          }
        ],
        dangerType: [
          {
            required: true,
            message: '隐患类型不能为空',
            trigger: 'blur'
          }
        ],
        checkUser: [
          {
            required: true,
            message: '检查人不能为空',
            trigger: 'blur'
          }
        ],
        checkDate: [
          {
            required: true,
            message: '检查时间不能为空',
            trigger: 'blur'
          }
        ],
        result: [
          {
            required: true,
            message: '检查结果不能为空',
            trigger: 'blur'
          }
        ]
      },
      types: [],
      units: [],
      isFc: false,
      isAdd: true,
      disabledFc: false,
      dialogImageUrl: '',
      dialogVisible: false,
      disabled: false,
      previewUrl:
        window.context.portal + '/file/onlinePreviewController/v1/getFileById_',
      uploadUrl: window.context.portal + '/file/v1/fileUpload' // 服务器上传地址
    }
  },
  created() {
    this.types = dictContracts.getDictItemsFromCache('cmgt_aqyhlx')
    this.greatDangerList = dictContracts.getDictItemsFromCache('ty-sf')
    // CmgtSaftyDangerCheckplanApi.loadAllUnit(res => {
    //   this.units = res
    // })
  },
  computed: mapState({
    header: state => {
      return {
        Authorization: `Bearer ${state.login.currentUser.token}`
      }
    }
  }),
  methods: {
    loadAllUnitList() {
      CmgtSaftyDangerCheckrecordApi.loadAllUnit(
        {
          pageBean: {pageSize: 20, page: -1}
        },
        res => {
          console.log(res)
          this.units = res.rows
          this.handleFcData.forEach(item => {
            this.units.forEach(val => {
              if (item.unitId == val.unitName) {
                item.unitId = val.id
              }
            })
          })
        }
      )
    },
    handleAvatarSuccess(res, file, fileList, row) {
      // row.imgUrl=[]
      console.log(res, file, fileList, row)
      if (res.success) {
        let arr = []
        arr.push({
          id: res.fileId,
          type: 'danger',
          url: this.previewUrl + res.fileId
        })
        row.imgs = row.imgs.concat(arr)
      } else {
        this.$message.error('上传文件失败！')
      }
    },
    handleAvatarSuccess1(res, file, fileList, row) {
      // row.imgUrl=[]
      console.log(res, file, fileList, row)
      if (res.success) {
        let arr = []
        arr.push({
          id: res.fileId,
          type: 'reform',
          url: this.previewUrl + res.fileId
        })
        row.reformImgs = row.reformImgs.concat(arr)
      } else {
        this.$message.error('上传文件失败！')
      }
    },
    // handleAvatarSuccess(res, file, fileList) {
    //   if (res.success) {
    //     this.params.baseInfoFileList.push({
    //       name: res.fileName,
    //       fileId: res.fileId,
    //       url: this.previewUrl + res.fileId
    //     })
    //   } else {
    //     this.$message.error('上传文件失败！')
    //   }
    // },
    // handleFcFileSuccess(res, file, fileList) {
    //   if (res.success) {
    //     this.params.fcFileList.push({
    //       name: res.fileName,
    //       fileId: res.fileId,
    //       url: this.previewUrl + res.fileId
    //     })
    //   } else {
    //     this.$message.error('上传文件失败！')
    //   }
    // },
    beforeAvatarUpload(file) {
      const isJPG =
        file.type === 'image/jpeg' ||
        file.type === 'image/png' ||
        file.type === 'image/jpg'
      const isLt1M = file.size / 1024 / 1024 < 10
      if (!isJPG) {
        this.$message.error('上传图片只能是 JPG 格式!')
      }
      if (!isLt1M) {
        this.$message.error('上传图片大小不能超过 1MB!')
      }
      return isJPG && isLt1M
    },
    handleClose() {
      // this.params = {
      //   id: null,
      //   checkplanId: null,
      //   dangerType: null,
      //   imark: null,
      //   checkDate: null,
      //   checkUser: null,
      //   content: null,
      //   recipient: null,
      //   location: null,
      //   result: null,
      //   danger: null,
      //   pcfa: null,
      //   reviewer: null,
      //   reviewDate: null,
      //   reviewResult: null,
      //   remainingProblem: null,
      //   timeLimit: null,
      //   resolver: null,
      //   resolvingOrg: null,
      //   resolvingMeasure: null,
      //   resolvingRemark: null,
      //   resolvingDate: null,
      //   status: null,
      //   sn: null,
      //   memo: null,
      //   createTime: null,
      //   baseInfoFiles: null,
      //   fcFiles: null,
      //   baseInfoFileList: [],
      //   fcFileList: []
      // }
      this.showFormDia = false
    },
    handleSave() {
      console.log(this.params)
      CmgtSaftyDangerCheckrecordApi.CSaftyDangerAbarbeitungReview(
        this.params,
        res => {
          if (res.state) {
            this.$notify({
              type: 'success',
              message: this.title + '成功',
              duration: 2000
            })
            this.$parent.loadData()
            this.handleClose()
          } else {
            this.$message.warning(res.message)
          }
        }
      )
      // this.$refs.formInfo.validate(valid => {
      //   if (valid) {
      //     let method
      //     if (!this.params.id) {
      //       // 新增
      //       method = CmgtSaftyDangerCheckrecordApi.addCmgtSaftyDangerCheckrecord
      //     }
      //     if (this.params.id) {
      //       // 修改
      //       method =
      //         CmgtSaftyDangerCheckrecordApi.editCmgtSaftyDangerCheckrecord
      //     }
      //     method(this.params, res => {
      //       if (res.state) {
      //         this.$notify({
      //           type: 'success',
      //           message: this.title + '成功',
      //           duration: 2000
      //         })
      //         this.$parent.loadData()
      //         this.handleClose()
      //       } else {
      //         this.$message.warning(res.message)
      //       }
      //     })
      //   }
      // })
    },
    Update(row) {
      this.params = this.handleFcData
      this.loadAllUnitList()
      console.log(this.handleFcData)
      // this.params = row
      // this.title = '录入复查'
      // this.params.status = '2'
      this.showFormDia = true
    },
    showInfo(row) {
      this.params = row
      this.title = '详细信息'
      this.showFormDia = true
    },

    handleRemove(file) {
      this.params.baseInfoFileList = this.params.baseInfoFileList.filter(
        item => {
          return item.fileId != file.fileId
        }
      )
    },
    handlePictureCardPreview(file) {
      this.dialogImageUrl = file.url
      this.dialogVisible = true
    },
    handleDownload(file) {
      CmgtSaftyDangerCheckrecordApi.downloadFile(file.fileId)
    },
    formaterUintName(id) {
      var obj = ''
      this.units.forEach(item => {
        if (item.id === id) {
          obj = item.unitName
        }
      })
      return obj
    }
  }
}
</script>
<style lang="scss" scoped>
::deep .el-collapse-item__content {
  padding-bottom: 0px;
}

.step-container {
  width: 80%;
  margin: 0 auto 20px;
}

.dialog-footer {
  text-align: center;
}
</style>
<style lang="scss" scoped>
::v-deep .el-upload--picture-card {
  width: 75px !important;
  height: 75px !important;
  line-height: 90px !important;
}

::v-deep .el-upload-list--picture-card .el-upload-list__item {
  width: 75px !important;
  height: 75px !important;
}
</style>
